@@ -1,30 +1,15 @@
 import ast
 import inspect
-from typing import Any, Optional
-
+from typing import Any, Optional, Union, get_origin
 import executing
 
-NAME_TOKEN = '__petit_name__'
-
 
 class AstFailure(Exception):
     ...
 
 
-# TODO: make a custom type that reflects the added functionnalities
-ExtendedBasicTypeHint = Any
-
-
-def get_extended_name(item: ExtendedBasicTypeHint) -> Optional[str]:
-    if hasattr(item, NAME_TOKEN):
-        return item.__dict__[NAME_TOKEN]
-    else:
-        return None
-
-
-def set_extended_name(item: ExtendedBasicTypeHint, name: Optional[str]) -> None:
-    if name is not None:
-        item.__dict__[NAME_TOKEN] = name
+class TooManyAssignments(Exception):
+    ...
 
 
 def get_parent_assign(node: ast.AST) -> ast.Assign:
@@ -34,7 +19,7 @@ def get_parent_assign(node: ast.AST) -> ast.Assign:
 
         if isinstance(node, ast.Assign):
             return node
-    raise Exception(
+    raise AstFailure(
         'Failed to retrieve the variable name.'
     )
 
@@ -45,18 +30,18 @@ def get_variable_name(with_raise: bool = True) -> Optional[str]:
     node = executing.Source.executing(frame).node
     try:
         assignment = get_parent_assign(node)
-    except:
-        return None
-    if len(assignment.targets) > 1:
+    except AstFailure as e:
         if with_raise:
-            raise AstFailure(
-                f"Too many assignments is not supported {ast.dump(assignment)}")
-        return None
+            raise e
+        else:
+            return None
     target = assignment.targets[0]
     if isinstance(target, ast.Name):
         return target.id
-    if isinstance(target, ast.Attribute):
-        return target.attr
+    if isinstance(target, ast.Tuple):
+        raise TooManyAssignments(
+            f"Can only work with one assignment"
+        )
     if with_raise:
         raise AstFailure(
             f"Can only get name of a variable or attribute, not {ast.dump(assignment)}"
