@@ -4,7 +4,7 @@ from abc import ABC, abstractstaticmethod
 from typing import Generic, TYPE_CHECKING, Any, Dict, List, Optional, Tuple, TypeVar, Union
 
 if TYPE_CHECKING:
-    from .petit_ts import TSTypeStore
+    from .petit_ts import TSTypeStore # pragma: no cover
 
 T = TypeVar('T')
 
@@ -17,23 +17,19 @@ class BaseHandler(ABC, Generic[T]):
 
     @abstractstaticmethod
     def build(cls: T, store: TSTypeStore, origin: Optional[type],
-              args: List[Any]) -> Tuple[Optional[str], Union[str, Dict[str, Any]]]: ...
+              args: List[Any], is_mapping_key:bool) -> Tuple[Optional[str], Union[str, Dict[str, Any]]]: ...
 
 
 class BasicHandler(BaseHandler[T]):
     @abstractstaticmethod
     def build(cls: T, store: TSTypeStore, origin: Optional[type],
-              args: List[Any]) -> Tuple[Optional[str], str]: ...
+              args: List[Any], is_mapping_key:bool) -> Tuple[Optional[str], str]: ...
 
 
 class ClassHandler(BaseHandler[T]):
     @abstractstaticmethod
     def is_mapping() -> bool: ...
 
-    @staticmethod
-    def is_inline(cls: type) -> bool:
-        return False
-
     @abstractstaticmethod
     def build(cls: T, store: TSTypeStore, origin: Optional[type],
-              args: List[Any]) -> Tuple[Optional[str], Union[str, Dict[str, Any]]]: ...
+              args: List[Any], is_mapping_key:bool) -> Tuple[Optional[str], Union[str, Dict[str, Any]]]: ...
